==> lasso_2.1.1.orig.tar.gz: lasso-2.1.1/lasso/xml/id-wsf-2.0/dstref_modify_item.c <==
/* $Id: dstref_modify_item.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
 *
 * Lasso - A free implementation of the Liberty Alliance specifications.
 *
 * Copyright (C) 2004-2007 Entr'ouvert
 * http://lasso.entrouvert.org
 * 
 * Authors: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "dstref_modify_item.h"

/*
 * Schema fragment (liberty-idwsf-dst-ref-v2.1.xsd):
 *
 * <xs:complexType name="ModifyItemType">
 *   <xs:sequence>
 *     <xs:element ref="dstref:Select" minOccurs="0" maxOccurs="1"/>
 *     <xs:element ref="dstref:NewData" minOccurs="0" maxOccurs="1"/>
 *   </xs:sequence>
 *   <xs:attributeGroup ref="dst:ModifyItemAttributeGroup"/>
 * </xs:complexType>
 */

/*****************************************************************************/
/* private methods                                                           */
/*****************************************************************************/


static struct XmlSnippet schema_snippets[] = {
	{ "Select", SNIPPET_CONTENT,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefModifyItem, Select) },
	{ "NewData", SNIPPET_NODE,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefModifyItem, NewData),
		"LassoIdWsf2DstRefAppData" },
	{ "notChangedSince", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefModifyItem, notChangedSince) },
	{ "overrideAllowed", SNIPPET_ATTRIBUTE | SNIPPET_BOOLEAN | SNIPPET_OPTIONAL,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefModifyItem, overrideAllowed) },
	{ "id", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefModifyItem, id) },
	{ "itemID", SNIPPET_ATTRIBUTE,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefModifyItem, itemID) },
	{NULL, 0, 0}
};

static LassoNodeClass *parent_class = NULL;


/*****************************************************************************/
/* instance and class init functions                                         */
/*****************************************************************************/

static void
instance_init(LassoIdWsf2DstRefModifyItem *node)
{
	node->Select = NULL;
	node->NewData = NULL;
	node->notChangedSince = NULL;
	node->overrideAllowed = FALSE;
	node->id = NULL;
	node->itemID = NULL;
}

static void
class_init(LassoIdWsf2DstRefModifyItemClass *klass)
{
	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);

	parent_class = g_type_class_peek_parent(klass);
	nclass->node_data = g_new0(LassoNodeClassData, 1);
	lasso_node_class_set_nodename(nclass, "ModifyItem");
	lasso_node_class_set_ns(nclass, LASSO_IDWSF2_DSTREF_HREF, LASSO_IDWSF2_DSTREF_PREFIX);
	lasso_node_class_add_snippets(nclass, schema_snippets);
}

GType
lasso_idwsf2_dstref_modify_item_get_type()
{
	static GType this_type = 0;

	if (!this_type) {
		static const GTypeInfo this_info = {
			sizeof (LassoIdWsf2DstRefModifyItemClass),
			NULL,
			NULL,
			(GClassInitFunc) class_init,
			NULL,
			NULL,
			sizeof(LassoIdWsf2DstRefModifyItem),
			0,
			(GInstanceInitFunc) instance_init,
		};

		this_type = g_type_register_static(LASSO_TYPE_NODE,
				"LassoIdWsf2DstRefModifyItem", &this_info, 0);
	}
	return this_type;
}

/**
 * lasso_idwsf2_dstref_modify_item_new:
 *
 * Creates a new #LassoIdWsf2DstRefModifyItem object.
 *
 * Return value: a newly created #LassoIdWsf2DstRefModifyItem object
 **/
LassoIdWsf2DstRefModifyItem*
lasso_idwsf2_dstref_modify_item_new()
{
	return g_object_new(LASSO_TYPE_IDWSF2_DSTREF_MODIFY_ITEM, NULL);
}

LassoIdWsf2DstRefModifyItem*
lasso_idwsf2_dstref_modify_item_new_full(const gchar *item_xpath, const gchar *item_id,
	xmlNode *new_data, const gboolean overrideAllowed)
{
	LassoIdWsf2DstRefModifyItem *item;

	item = g_object_new(LASSO_TYPE_IDWSF2_DSTREF_MODIFY_ITEM, NULL);
	item->Select = g_strdup(item_xpath);
	item->id = g_strdup(item_id);
	item->NewData = lasso_idwsf2_dstref_app_data_new();
	item->NewData->any = g_list_append(item->NewData->any, new_data);
	item->overrideAllowed = overrideAllowed;

	return item;
}

==> lasso_2.2.1.orig.tar.gz: lasso-2.2.1/lasso/xml/id-wsf-2.0/dstref_modify_item.c <==
/* $Id: dstref_modify_item.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
 *
 * Lasso - A free implementation of the Liberty Alliance specifications.
 *
 * Copyright (C) 2004-2007 Entr'ouvert
 * http://lasso.entrouvert.org
 * 
 * Authors: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "dstref_modify_item.h"

/**
 * SECTION:dstref_modify_item
 * @short_description: &lt;dstref:ModifyItem&gt;
 *
 * <figure><title>Schema fragment for dstref:ModifyItem</title>
 * <programlisting><![CDATA[
 *
 * <xs:complexType name="ModifyItemType">
 *   <xs:sequence>
 *     <xs:element ref="dstref:Select" minOccurs="0" maxOccurs="1"/>
 *     <xs:element ref="dstref:NewData" minOccurs="0" maxOccurs="1"/>
 *   </xs:sequence>
 *   <xs:attributeGroup ref="dst:ModifyItemAttributeGroup"/>
 * </xs:complexType>
 * ]]></programlisting>
 * </figure>
 */

/*****************************************************************************/
/* private methods                                                           */
/*****************************************************************************/


static struct XmlSnippet schema_snippets[] = {
	{ "Select", SNIPPET_CONTENT,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefModifyItem, Select) },
	{ "NewData", SNIPPET_NODE,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefModifyItem, NewData),
		"LassoIdWsf2DstRefAppData" },
	{ "notChangedSince", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefModifyItem, notChangedSince) },
	{ "overrideAllowed", SNIPPET_ATTRIBUTE | SNIPPET_BOOLEAN | SNIPPET_OPTIONAL,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefModifyItem, overrideAllowed) },
	{ "id", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefModifyItem, id) },
	{ "itemID", SNIPPET_ATTRIBUTE,
		G_STRUCT_OFFSET(LassoIdWsf2DstRefModifyItem, itemID) },
	{NULL, 0, 0}
};

static LassoNodeClass *parent_class = NULL;


/*****************************************************************************/
/* instance and class init functions                                         */
/*****************************************************************************/

static void
instance_init(LassoIdWsf2DstRefModifyItem *node)
{
	node->Select = NULL;
	node->NewData = NULL;
	node->notChangedSince = NULL;
	node->overrideAllowed = FALSE;
	node->id = NULL;
	node->itemID = NULL;
}

static void
class_init(LassoIdWsf2DstRefModifyItemClass *klass)
{
	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);

	parent_class = g_type_class_peek_parent(klass);
	nclass->node_data = g_new0(LassoNodeClassData, 1);
	lasso_node_class_set_nodename(nclass, "ModifyItem");
	lasso_node_class_set_ns(nclass, LASSO_IDWSF2_DSTREF_HREF, LASSO_IDWSF2_DSTREF_PREFIX);
	lasso_node_class_add_snippets(nclass, schema_snippets);
}

GType
lasso_idwsf2_dstref_modify_item_get_type()
{
	static GType this_type = 0;

	if (!this_type) {
		static const GTypeInfo this_info = {
			sizeof (LassoIdWsf2DstRefModifyItemClass),
			NULL,
			NULL,
			(GClassInitFunc) class_init,
			NULL,
			NULL,
			sizeof(LassoIdWsf2DstRefModifyItem),
			0,
			(GInstanceInitFunc) instance_init,
		};

		this_type = g_type_register_static(LASSO_TYPE_NODE,
				"LassoIdWsf2DstRefModifyItem", &this_info, 0);
	}
	return this_type;
}

/**
 * lasso_idwsf2_dstref_modify_item_new:
 *
 * Creates a new #LassoIdWsf2DstRefModifyItem object.
 *
 * Return value: a newly created #LassoIdWsf2DstRefModifyItem object
 **/
LassoIdWsf2DstRefModifyItem*
lasso_idwsf2_dstref_modify_item_new()
{
	return g_object_new(LASSO_TYPE_IDWSF2_DSTREF_MODIFY_ITEM, NULL);
}

LassoIdWsf2DstRefModifyItem*
lasso_idwsf2_dstref_modify_item_new_full(const gchar *item_xpath, const gchar *item_id,
	xmlNode *new_data, gboolean overrideAllowed)
{
	LassoIdWsf2DstRefModifyItem *item;

	item = g_object_new(LASSO_TYPE_IDWSF2_DSTREF_MODIFY_ITEM, NULL);
	item->Select = g_strdup(item_xpath);
	item->id = g_strdup(item_id);
	item->NewData = lasso_idwsf2_dstref_app_data_new();
	item->NewData->any = g_list_append(item->NewData->any, new_data);
	item->overrideAllowed = overrideAllowed;

	return item;
}
